# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative_filter_name import RepresentativeFilterName

class TestRepresentativeFilterName(unittest.TestCase):
    """RepresentativeFilterName unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepresentativeFilterName:
        """Test RepresentativeFilterName
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepresentativeFilterName`
        """
        model = RepresentativeFilterName()
        if include_optional:
            return RepresentativeFilterName(
                eq = '',
                greater_than = '',
                greater_than_or_equal = '',
                var_in = [
                    ''
                    ],
                is_nil = True,
                less_than = '',
                less_than_or_equal = '',
                not_eq = ''
            )
        else:
            return RepresentativeFilterName(
        )
        """

    def testRepresentativeFilterName(self):
        """Test RepresentativeFilterName"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



"""inhabitant"""
import typer


app = typer.Typer()


@app.command(name="inhabitant")
def _inhabitant():
    """inhabitant"""
    typer.echo("Running inhabitant subcommand.")
     
@app.command(name="add")
def inhabitant_add():
    """add"""
    typer.echo("Running add subcommand.")
 
@app.command(name="remove")
def inhabitant_remove():
    """remove"""
    typer.echo("Running remove subcommand.")
 
@app.command(name="list")
def inhabitant_list():
    """list"""
    typer.echo("Running list subcommand.")
 
@app.command(name="start")
def inhabitant_start():
    """start"""
    typer.echo("Running start subcommand.")
 
@app.command(name="stop")
def inhabitant_stop():
    """stop"""
    typer.echo("Running stop subcommand.")
 
@app.command(name="logs")
def inhabitant_logs():
    """logs"""
    typer.echo("Running logs subcommand.")



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.ticket_relationships import TicketRelationships

class TestTicketRelationships(unittest.TestCase):
    """TicketRelationships unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TicketRelationships:
        """Test TicketRelationships
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TicketRelationships`
        """
        model = TicketRelationships()
        if include_optional:
            return TicketRelationships(
                representative = openapi_client.models.ticket_relationships_representative.ticket_relationships_representative(
                    data = [
                        openapi_client.models.ticket_relationships_representative_data_inner.ticket_relationships_representative_data_inner(
                            id = '', 
                            meta = { }, 
                            type = '', )
                        ], )
            )
        else:
            return TicketRelationships(
        )
        """

    def testTicketRelationships(self):
        """Test TicketRelationships"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.ticket_api import TicketApi


class TestTicketApi(unittest.TestCase):
    """TicketApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TicketApi()

    def tearDown(self) -> None:
        pass

    def test_tickets_get(self) -> None:
        """Test case for tickets_get

        """
        pass

    def test_tickets_id_get(self) -> None:
        """Test case for tickets_id_get

        """
        pass

    def test_tickets_id_patch(self) -> None:
        """Test case for tickets_id_patch

        """
        pass

    def test_tickets_post(self) -> None:
        """Test case for tickets_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representatives_get200_response import RepresentativesGet200Response

class TestRepresentativesGet200Response(unittest.TestCase):
    """RepresentativesGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepresentativesGet200Response:
        """Test RepresentativesGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepresentativesGet200Response`
        """
        model = RepresentativesGet200Response()
        if include_optional:
            return RepresentativesGet200Response(
                data = [
                    openapi_client.models.representative.representative(
                        attributes = openapi_client.models.representative_attributes.representative_attributes(
                            name = '', ), 
                        id = '', 
                        relationships = openapi_client.models.representative_relationships.representative_relationships(
                            tickets = openapi_client.models.representative_relationships_tickets.representative_relationships_tickets(
                                data = [
                                    openapi_client.models.representative_relationships_tickets_data_inner.representative_relationships_tickets_data_inner(
                                        id = '', 
                                        meta = { }, 
                                        type = '', )
                                    ], ), ), 
                        type = '', )
                    ],
                included = [
                    null
                    ],
                meta = { }
            )
        else:
            return RepresentativesGet200Response(
        )
        """

    def testRepresentativesGet200Response(self):
        """Test RepresentativesGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



"""marketplace"""
import typer


app = typer.Typer()


@app.command(name="marketplace")
def marketplace_marketplace():
    """marketplace"""
    typer.echo("Running marketplace subcommand.")
     
@app.command(name="list")
def marketplace_list():
    """list"""
    typer.echo("Running list subcommand.")
 
@app.command(name="install")
def marketplace_install():
    """install"""
    typer.echo("Running install subcommand.")
 
@app.command(name="uninstall")
def marketplace_uninstall():
    """uninstall"""
    typer.echo("Running uninstall subcommand.")
 
@app.command(name="update")
def marketplace_update():
    """update"""
    typer.echo("Running update subcommand.")
 
@app.command(name="search")
def marketplace_search():
    """search"""
    typer.echo("Running search subcommand.")



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.tickets_id_patch_request_data import TicketsIdPatchRequestData

class TestTicketsIdPatchRequestData(unittest.TestCase):
    """TicketsIdPatchRequestData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TicketsIdPatchRequestData:
        """Test TicketsIdPatchRequestData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TicketsIdPatchRequestData`
        """
        model = TicketsIdPatchRequestData()
        if include_optional:
            return TicketsIdPatchRequestData(
                attributes = openapi_client.models._tickets__id__patch_request_data_attributes._tickets__id__patch_request_data_attributes(
                    representative_id = '', ),
                id = '',
                relationships = None,
                type = 'ticket'
            )
        else:
            return TicketsIdPatchRequestData(
                id = '',
        )
        """

    def testTicketsIdPatchRequestData(self):
        """Test TicketsIdPatchRequestData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative_filter import RepresentativeFilter

class TestRepresentativeFilter(unittest.TestCase):
    """RepresentativeFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepresentativeFilter:
        """Test RepresentativeFilter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepresentativeFilter`
        """
        model = RepresentativeFilter()
        if include_optional:
            return RepresentativeFilter(
                var_and = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        or = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    or = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                id = openapi_client.models.representative_filter_id.representative-filter-id(
                    eq = '', 
                    greater_than = '', 
                    greater_than_or_equal = '', 
                    in = [
                        ''
                        ], 
                    is_nil = True, 
                    less_than = '', 
                    less_than_or_equal = '', 
                    not_eq = '', ),
                name = openapi_client.models.representative_filter_name.representative-filter-name(
                    eq = '', 
                    greater_than = '', 
                    greater_than_or_equal = '', 
                    in = [
                        ''
                        ], 
                    is_nil = True, 
                    less_than = '', 
                    less_than_or_equal = '', 
                    not_eq = '', ),
                var_not = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        or = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    or = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                var_or = openapi_client.models.representative_filter.representative-filter(
                    and = openapi_client.models.representative_filter.representative-filter(
                        id = openapi_client.models.representative_filter_id.representative-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        name = openapi_client.models.representative_filter_name.representative-filter-name(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        tickets = openapi_client.models.ticket_filter.ticket-filter(
                            representative = , 
                            representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), 
                            subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), ), 
                    id = openapi_client.models.representative_filter_id.representative-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    name = openapi_client.models.representative_filter_name.representative-filter-name(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    tickets = openapi_client.models.ticket_filter.ticket-filter(), ),
                tickets = openapi_client.models.ticket_filter.ticket-filter(
                    and = openapi_client.models.ticket_filter.ticket-filter(
                        id = openapi_client.models.ticket_filter_id.ticket-filter-id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            in = [
                                ''
                                ], 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        not = , 
                        or = , 
                        representative = openapi_client.models.representative_filter.representative-filter(
                            name = openapi_client.models.representative_filter_name.representative-filter-name(
                                eq = '', 
                                greater_than = '', 
                                greater_than_or_equal = '', 
                                is_nil = True, 
                                less_than = '', 
                                less_than_or_equal = '', 
                                not_eq = '', ), ), 
                        representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), 
                        subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                            eq = '', 
                            greater_than = '', 
                            greater_than_or_equal = '', 
                            is_nil = True, 
                            less_than = '', 
                            less_than_or_equal = '', 
                            not_eq = '', ), ), 
                    id = openapi_client.models.ticket_filter_id.ticket-filter-id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    not = , 
                    or = , 
                    representative = openapi_client.models.representative_filter.representative-filter(), 
                    representative_id = openapi_client.models.ticket_filter_representative_id.ticket-filter-representative_id(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), 
                    subject = openapi_client.models.ticket_filter_subject.ticket-filter-subject(
                        eq = '', 
                        greater_than = '', 
                        greater_than_or_equal = '', 
                        is_nil = True, 
                        less_than = '', 
                        less_than_or_equal = '', 
                        not_eq = '', ), )
            )
        else:
            return RepresentativeFilter(
        )
        """

    def testRepresentativeFilter(self):
        """Test RepresentativeFilter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import typer
from rich import print
from sungen.utils.cli_tools import load_commands
from sungen.utils.file_tools import source_dir
import speech_recognition as sr
import os

app = typer.Typer()

load_commands(app, source_dir("cmds"))

@app.command()
def fire(name: str = "Chell") -> None:
    """Fire portal gun."""
    print(f"[bold red]Alert![/bold red] {name} fired [green]portal gun[/green] :boom:")
    on_key_press1()


def process_voice_command():
    recognizer = sr.Recognizer()
    with sr.Microphone() as source:
        print("Listening...")
        recognizer.adjust_for_ambient_noise(source)  # Adjust for background noise

        # Loop to continuously listen and recognize speech
        while True:
            try:
                print("Listening for a command...")
                audio = recognizer.listen(source, phrase_time_limit=5)  # Listen for a maximum of 5 seconds per phrase

                # Recognize the audio and convert it to text
                command = recognizer.recognize_google(audio).lower()
                print(f"You said: {command}")

                yield command  # Yield the recognized command for processing
            except sr.UnknownValueError:
                print("Sorry, I didn't understand that.")
            except sr.RequestError:
                print("Sorry, there was an issue connecting to the service.")
                break

def on_key_press1():
    # Streaming the recognized text
    for command in process_voice_command():
        if "run" in command or "execute" in command or "open" in command or "start" in command:
            if "finder" in command and ("don't" or "not") not in command:
                os.system("open /System/Library/CoreServices/Finder.app")
            elif "textedit" in command and ("don't" or "not") not in command:
                os.system("open -a TextEdit")
            elif "safari" in command and ("don't" or "not") not in command:
                os.system("open -a Safari")
            elif "chrome" in command and ("don't" or "not") not in command:
                os.system("open -a 'Google Chrome'")
            elif "calculator" in command and ("don't" or "not") not in command:
                os.system("open -a Calculator")
            else:
                print("Command not supported.")

        elif "goodbye" in command:
            print("Goodbye! Have a great day!")
            quit()  # Exit the program

        elif "stop" in command:
            print("Stopping the voice recognition system.")
            quit()  # Exit the program

        else:
            print("Command not supported.")


 
def main():
    """Main function"""

if __name__ == '__main__':
    main()



# coding: utf-8

"""
    Open API Specification

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.representative import Representative

class TestRepresentative(unittest.TestCase):
    """Representative unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Representative:
        """Test Representative
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Representative`
        """
        model = Representative()
        if include_optional:
            return Representative(
                attributes = openapi_client.models.representative_attributes.representative_attributes(
                    name = '', ),
                id = '',
                relationships = openapi_client.models.representative_relationships.representative_relationships(
                    tickets = openapi_client.models.representative_relationships_tickets.representative_relationships_tickets(
                        data = [
                            openapi_client.models.representative_relationships_tickets_data_inner.representative_relationships_tickets_data_inner(
                                id = '', 
                                meta = { }, 
                                type = '', )
                            ], ), ),
                type = ''
            )
        else:
            return Representative(
                id = '',
                type = '',
        )
        """

    def testRepresentative(self):
        """Test Representative"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
